"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decompress = exports.compress = void 0;
const zlib = require("zlib");
/**
 * Compress utf8 string to base64 string
 *
 * @param text utf8 string
 * @returns base64 string
 */
async function compress(text) {
    return new Promise((resolve, reject) => {
        const buffer = Buffer.from(text);
        return zlib.gzip(buffer, { level: 3 }, (error, res) => {
            if (error) {
                return reject(error);
            }
            return resolve(res.toString('base64'));
        });
    });
}
exports.compress = compress;
/**
 * Decompress base64 string to utf8 string
 *
 * @param text base64 string
 * @returns utf8 string
 */
async function decompress(text) {
    return new Promise((resolve, reject) => {
        const buffer = Buffer.from(text, 'base64');
        return zlib.gunzip(buffer, (error, res) => {
            if (error) {
                return reject(error);
            }
            return resolve(res.toString());
        });
    });
}
exports.decompress = decompress;
exports.default = {
    compress,
    decompress,
};
